katsdpimager.test.test\_loader\_katdal module
=============================================

.. automodule:: katsdpimager.test.test_loader_katdal
   :members:
   :undoc-members:
   :show-inheritance:
